from __future__ import absolute_import

import operator

from toolz.functoolz import curry


# Tests will catch if/when this needs updated
IGNORE = {
    "__abs__", "__index__", "__inv__", "__invert__", "__neg__", "__not__",
    "__pos__", "_abs", "abs", "attrgetter", "index", "inv", "invert",
    "itemgetter", "neg", "not_", "pos", "truth"
}
locals().update(
    {name: f if name in IGNORE else curry(f)
     for name, f in vars(operator).items() if callable(f)}
)

# Clean up the namespace.
del IGNORE
del curry
del operator



print("import: 'tlz'")
import tlz

print("import: 'toolz'")
import toolz

print("import: 'toolz.curried'")
import toolz.curried

print("import: 'toolz.functoolz'")
import toolz.functoolz

print("import: 'toolz.sandbox'")
import toolz.sandbox




from .itertoolz import *

from .functoolz import *

from .dicttoolz import *

from .recipes import *

from functools import partial, reduce

sorted = sorted

map = map

filter = filter

# Aliases
comp = compose

from . import curried, sandbox

functoolz._sigs.create_signature_registry()

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions
